"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListTagsForResource = void 0;
const ListTagsForResourceCommand_1 = require("../commands/ListTagsForResourceCommand");
const DataSync_1 = require("../DataSync");
const DataSyncClient_1 = require("../DataSyncClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListTagsForResourceCommand_1.ListTagsForResourceCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listTagsForResource(input, ...args);
};
async function* paginateListTagsForResource(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof DataSync_1.DataSync) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof DataSyncClient_1.DataSyncClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected DataSync | DataSyncClient");
        }
        yield page;
        token = page.NextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateListTagsForResource = paginateListTagsForResource;
