import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { DataSyncClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../DataSyncClient";
import { CreateLocationHdfsRequest, CreateLocationHdfsResponse } from "../models/models_0";
export interface CreateLocationHdfsCommandInput extends CreateLocationHdfsRequest {
}
export interface CreateLocationHdfsCommandOutput extends CreateLocationHdfsResponse, __MetadataBearer {
}
/**
 * <p>Creates an endpoint for a Hadoop Distributed File System (HDFS). </p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { DataSyncClient, CreateLocationHdfsCommand } from "@aws-sdk/client-datasync"; // ES Modules import
 * // const { DataSyncClient, CreateLocationHdfsCommand } = require("@aws-sdk/client-datasync"); // CommonJS import
 * const client = new DataSyncClient(config);
 * const command = new CreateLocationHdfsCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link CreateLocationHdfsCommandInput} for command's `input` shape.
 * @see {@link CreateLocationHdfsCommandOutput} for command's `response` shape.
 * @see {@link DataSyncClientResolvedConfig | config} for DataSyncClient's `config` shape.
 *
 */
export declare class CreateLocationHdfsCommand extends $Command<CreateLocationHdfsCommandInput, CreateLocationHdfsCommandOutput, DataSyncClientResolvedConfig> {
    readonly input: CreateLocationHdfsCommandInput;
    constructor(input: CreateLocationHdfsCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: DataSyncClientResolvedConfig, options?: __HttpHandlerOptions): Handler<CreateLocationHdfsCommandInput, CreateLocationHdfsCommandOutput>;
    private serialize;
    private deserialize;
}
